# KSearcH
**KSearcH** — это библиотека для быстрого и эффективного поиска по текстовым данным. Она позволяет индексировать и искать информацию с минимальными затратами ресурсов.

## Установка

Чтобы установить библиотеку, выполните команду:

```bash
pip install ksearch
```